@@ -9,15 +9,7 @@ from nowcasting_dataset.dataset.batch import Batch
 from nowcasting_dataset.time import make_random_time_vectors
 from pydantic import BaseModel, Field
 
-from nowcasting_dataloader.data_sources import (
-    GSPML,
-    NWPML,
-    PVML,
-    MetadataML,
-    SatelliteML,
-    SunML,
-    TopographicML,
-)
+from nowcasting_dataloader.data_sources import GSPML, NWPML, PVML, SatelliteML, SunML, TopographicML
 from nowcasting_dataloader.xr_utils import (
     register_xr_data_array_to_tensor,
     register_xr_data_set_to_tensor,
@@ -36,7 +28,6 @@ class Example(BaseModel):
     Note that this is currently not really used
     """
 
-    metadata: Optional[MetadataML]
     satellite: Optional[SatelliteML]
     topographic: Optional[TopographicML]
     pv: Optional[PVML]
@@ -54,7 +45,7 @@ class Example(BaseModel):
             self.sun,
             self.gsp,
             self.nwp,
-            self.metadata,
+            # self.metadata,
         ]
 
 
@@ -93,7 +84,6 @@ class BatchML(Example):
 
         return BatchML(
             batch_size=process.batch_size,
-            metadata=MetadataML.fake(batch_size=process.batch_size, t0_dt=t0_dt),
             satellite=SatelliteML.fake(
                 process.batch_size,
                 input_data.default_seq_length_5_minutes,
