@@ -2,6 +2,7 @@
 from __future__ import annotations
 
 import logging
+from typing import Optional
 
 import numpy as np
 import xarray as xr
@@ -9,7 +10,7 @@ from nowcasting_dataset.time import make_random_time_vectors
 from pydantic import Field
 
 from nowcasting_dataloader.data_sources.datasource_output import Array, DataSourceOutputML
-from nowcasting_dataloader.utils.dims import re_order_dims
+from nowcasting_dataloader.xr_utils import re_order_dims
 
 logger = logging.getLogger(__name__)
 
@@ -71,7 +72,7 @@ class SatelliteML(DataSourceOutputML):
         "passed into the ML model.",
     )
 
-    channels: Array = Field(..., description="List of the satellite channels")
+    channels: Optional[Array] = Field(None, description="List of the satellite channels")
 
     @staticmethod
     def fake(
@@ -118,7 +119,7 @@ class SatelliteML(DataSourceOutputML):
         xr_dataset = re_order_dims(xr_dataset)
 
         # convert to torch dictionary
-        satellite_batch_ml = xr_dataset.torch.to_tensor(["data", "time", "x", "y", "channels"])
+        satellite_batch_ml = xr_dataset.torch.to_tensor(["data", "time", "x", "y"])
 
         # move to Modle
         return SatelliteML(**satellite_batch_ml)
