@@ -235,13 +235,12 @@ def encode_absolute_position(
             year_features = encode_year(datetimes, time_range)
             # Repeat
             year_features = einops.repeat(
-                year_features, "b t -> b (repeat t)", repeat=shape[TIME_DIM]
+                year_features, "b t c -> b (repeat t) c", repeat=shape[TIME_DIM]
             )
             datetime_features.append(year_features)
         absolute_position_encoding = combine_space_and_time_features(
             absolute_position_encoding, datetime_features=datetime_features, shape=shape
         )
-
     return absolute_position_encoding
 
 
@@ -264,10 +263,10 @@ def combine_space_and_time_features(
     for date_feature in datetime_features:
         if len(shape) == 5:
             date_feature = einops.repeat(
-                date_feature, "b t -> b c t h w", h=shape[HEIGHT_DIM], w=shape[WIDTH_DIM], c=1
+                date_feature, "b t c -> b c t h w", h=shape[HEIGHT_DIM], w=shape[WIDTH_DIM]
             )
         else:
-            date_feature = einops.repeat(date_feature, "b t -> b c t id", id=shape[ID_DIM], c=1)
+            date_feature = einops.repeat(date_feature, "b t c -> b c t id", id=shape[ID_DIM])
         to_concat.append(date_feature)
     space_and_time_encoding = torch.cat(to_concat, dim=1)
     return space_and_time_encoding
@@ -350,7 +349,9 @@ def encode_year(
         # Rescale between -1 and 1
         encoding *= 2
         encoding -= 1
-        year_encoding.append(torch.as_tensor([encoding]))
+        # Compute Fourier Features
+        encoding = fourier_encode(torch.as_tensor([encoding]), max_freq=99, num_bands=12)
+        year_encoding.append(encoding)
     year_encoding = torch.stack(year_encoding, dim=0)
     return year_encoding
 
@@ -374,19 +375,19 @@ def create_datetime_features(
         days = []
         for index in datetimes[batch_idx]:
             time_index = pd.Timestamp(index)
-            hours.append((time_index.hour + (time_index.minute / 60) / 24))
-            days.append((time_index.timetuple().tm_yday / 366))  # To take care of leap years
+            hours.append((((time_index.hour + (time_index.minute / 60)) / 24) * 2) - 1)
+            days.append(((time_index.timetuple().tm_yday / 366) * 2) - 1)
         hour_of_day.append(hours)
         day_of_year.append(days)
 
     outputs = []
-    for index in [hour_of_day, day_of_year]:
-        index = torch.as_tensor(index)
-        radians = index * 2 * np.pi
-        index_sin = torch.sin(radians)
-        index_cos = torch.cos(radians)
-        outputs.append(index_sin)
-        outputs.append(index_cos)
+    hour_of_day = torch.as_tensor(hour_of_day)
+    day_of_year = torch.as_tensor(day_of_year)
+    # Compute Fourier Features
+    hour_of_day = fourier_encode(hour_of_day, max_freq=47, num_bands=6)
+    day_of_year = fourier_encode(day_of_year, max_freq=731, num_bands=6)
+    outputs.append(hour_of_day)
+    outputs.append(day_of_year)
 
     return outputs
 
